"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getSuggestedIndentSize = exports.getIndentSize = exports.createIndentString = exports.INDENT_SYMBOL = exports.INDENT_SIZE = void 0;
var Braces = _interopRequireWildcard(require("./braces"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const INDENT_SIZE = exports.INDENT_SIZE = 2; // Better for small screens
const INDENT_SYMBOL = exports.INDENT_SYMBOL = ' '; // Spaces over tabs

/**
 * Gets the indentation size of the given line of code.
 * @param line Line of code.
 * @returns number.
 */
const getIndentSize = line => {
  for (let i = 0; i < line.length; i++) {
    if (line[i] !== INDENT_SYMBOL) {
      const trimmed = line.trimEnd();
      const lastChar = trimmed.substring(trimmed.length - 1);
      // Extra indentation if inside a regular brace.
      // Inclues colon for python.
      const addedIndent = Braces.isOpenBrace(lastChar, true) || lastChar === ':' ? INDENT_SIZE : 0;
      return i + addedIndent;
    }
  }
  return 0;
};

/**
 * Analyses the lines of code (from end to start) and finds
 * the best indentation size for the new line.
 * @param lines The lines of code to analyze.
 * @returns number
 */
exports.getIndentSize = getIndentSize;
const getSuggestedIndentSize = lines => {
  for (let i = lines.length - 1; i >= 0; i--) {
    if (lines[i].trim().length > 0) {
      return getIndentSize(lines[i]);
    }
  }
  return 0;
};

/**
 * Creates an indentation string of the given size.
 * The preset indentation size is used by default.
 * @param indentSize Optional indentation size.
 * @returns string
 */
exports.getSuggestedIndentSize = getSuggestedIndentSize;
const createIndentString = function () {
  let indentSize = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : INDENT_SIZE;
  let str = '';
  for (let i = 0; i < indentSize; i++) {
    str += INDENT_SYMBOL;
  }
  return str;
};
exports.createIndentString = createIndentString;
//# sourceMappingURL=indentation.js.map